UsernamePasswordCredential class

Inheritance

Constructors

UsernamePasswordCredential(String username, String password)

Properties

hashCode → int
The hash code for this object.
no setterinherited
password → String
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
username → String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toPigeonCredential() → UsernamePasswordCredential
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited