IdToken class

Constructors

IdToken(String idToken, String accessToken, String refreshToken, int expiresIn, String tokenType)

Properties

accessToken → String
final
expiresIn → int
final
hashCode → int
The hash code for this object.
no setterinherited
idToken → String
final
refreshToken → String
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
tokenType → String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited