UserInfo class

Constructors

UserInfo(String? sub, String? name, String? picture, String? email, String? phoneNumber, String? birthday, String? address, List<String>? roles, List<String>? permissions, Map<String, Object?>? metadata)

Properties

address → String?
final
birthday → String?
final
email → String?
final
hashCode → int
The hash code for this object.
no setterinherited
metadata → Map<String, Object?>?
final
name → String?
final
permissions → List<String>?
final
phoneNumber → String?
final
picture → String?
final
roles → List<String>?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
sub → String?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited