TerraAuth class

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

confirmEmail(String email, String code) → Future<Result<void, Exception>>
confirmPhone(String phone, String code) → Future<Result<void, Exception>>
exchangeToken(String iamAudience) → Future<Result<IdToken, Exception>>
getAccessToken() → Future<Result<IamToken, Exception>>
getLoginResult(Future<CommonAuthResult> function()) → Future<Result<bool, Exception>>
getUserInfo() → Future<Result<UserInfo, Exception>>
isAuthorized() → Future<Result<bool, Exception>>
loginWithApple() → Future<Result<bool, Exception>>
loginWithCredential(LoginCredential credential) → Future<Result<bool, Exception>>
loginWithFacebook() → Future<Result<bool, Exception>>
loginWithGoogle() → Future<Result<bool, Exception>>
logout() → Future<Result<bool, Exception>>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
refreshToken() → Future<Result<IamToken, Exception>>
requestOtp(String phoneNumber) → Future<Result<Object, Exception>>
toString() → String
A string representation of this object.
inherited
verifyEmail(String email) → Future<Result<void, Exception>>
verifyPhone(String phone) → Future<Result<void, Exception>>

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

getInstance(String appName) → Future<TerraAuth>